/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef CONFIGHANDLER_H
#define CONFIGHANDLER_H

#include <QDir>
#include <QListView>
#include "configmodel.h"
#include "configdelegate.h"


class ConfigHandler : public QObject
{
	Q_OBJECT

public:
	ConfigHandler(QObject *parent = 0);
	~ConfigHandler();
	void connectListView(QListView *ptr);
	void disconnectListView(QListView *ptr);
	void changeCfgDir(QString newDir);
	QString getCurrentCfgName(QListView *listView);
	QString getCurrentCfgPath(QListView *listView);
	QString getCfgPath(QString cfgName);
	QString generateCfgPath(QString newCfgName);
	void removeCurrentCfg(QListView *listView);
	bool create(QString newCfgPath, QString newCfgName);
	bool duplicate(QString sourceCfgName, QString newCfgName);
	void insertConfiguration(Configuration *cfg) const;
	bool configurationExists(QString cfgName);
	static ConfigHandler *instance() { return self; };

private:
	QDir cfgDir;
	QList<QListView*> listView_list;
	QList<Configuration*> cfgList;
	static ConfigHandler *self;
	ConfigModel *cfgModel;
	void populateCfgList();
	bool initializeCfgDir();

};

#endif
