/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "createdialog.h"
#include "confighandler.h"
#include <QMessageBox>
#include "macros.h"
#include "configdelegate.h"

CreateDialog::CreateDialog(bool duplicateEnabled, QWidget *parent)
 : QDialog(parent)
{
	dlg.setupUi(this);
	dlg.DuplicateBox->setEnabled(duplicateEnabled);
}

void CreateDialog::on_okButton_clicked()
{
	if ( cfgHandler->configurationExists(dlg.nameEdit->text()) ) {
		QMessageBox::critical(this, "Error", "A configuration with that name already exists", "OK");
		return;
	}

	WAIT_MESSAGE;

	if ( dlg.DuplicateBox->isChecked() ) {
		if ( !cfgHandler->duplicate(dlg.cfgToCopyLabel->text(), dlg.nameEdit->text()) ) return;
	} else {
		if ( !cfgHandler->create( cfgHandler->generateCfgPath(dlg.nameEdit->text()) , dlg.nameEdit->text()) ) return;
	}

	accept();
	// splash screen is deleted here
}

void CreateDialog::on_cfgToCopyButton_clicked()
{
	QString selectedConfiguration;
	CreateDialogSelector a(&selectedConfiguration, this);
	if (a.exec())
		dlg.cfgToCopyLabel->setText(selectedConfiguration);
}



CreateDialogSelector::CreateDialogSelector(QString *str, QWidget *parent)
	:QDialog(parent)
{
	selectedCfg = str;
	dlg.setupUi(this);
	cfgHandler->connectListView(dlg.listView);

	DummyDelegate *delegate = new DummyDelegate;
	dlg.listView->setItemDelegate( delegate );
}

CreateDialogSelector::~CreateDialogSelector()
{
	cfgHandler->disconnectListView(dlg.listView);
}

void CreateDialogSelector::on_okButton_clicked()
{
	*selectedCfg = cfgHandler->getCurrentCfgName(dlg.listView);
}
